'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var preact = require('preact');
var reshapePreactComponents = require('reshape-preact-components');
var NewsletterSignupForm = _interopDefault(require('@hashicorp/hashi-newsletter-signup-form'));

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
  NOTE: Footer Links Section Headers

  Per:
  ZD #122 - Make subheading for footer sections editable in DatoCMS
  https://app.asana.com/0/346384260719996/953739534334773/f

  The following fields were added to DatoCMS via the data object:
  * products, resources, partners, and company

  These new fields act as headers to the related link fields:
  * all_product_links, resource_links, partner_links, and company_links

  This was initial implemented as a light touch minimal solution as we are
  trying to determine our needs for a data structure while enabling Marcel
  to begin testing different link sets in the footer.

  This may include changes to the Footer Link Section Headers which no longer
  make sense. For example, in DatoCMS we can now change the Product header
  to any other string. The concern is that this may cause confusion down the
  line. As such, the following follow up ticket was created to re-evaluate our
  needs after more experiementation has been done with the Footer Links.

  Editable Footer Links via DatoCMS - Follow Up
  https://app.asana.com/0/346384260719996/1115770860790862/f
*/

function Footer(_ref) {
  var _data = _ref._data,
      _state = _ref._state,
      hide_top = _ref.hide_top;

  var data = reshapePreactComponents.decode(_data);
  return preact.h(
    'footer',
    { 'class': 'g-footer', 'data-state': _state },
    preact.h(
      'div',
      { 'class': 'g-container' },
      !hide_top && preact.h(
        'div',
        { 'class': 'top' },
        preact.h(
          'div',
          { 'class': 'newsletter-form' },
          preact.h(NewsletterSignupForm, { on_dark: true })
        ),
        preact.h(
          'ul',
          null,
          data.social_links.map(function (link, index) {
            return preact.h(
              'li',
              { key: 'social-' + index },
              preact.h(
                'a',
                {
                  'data-ga-footer': 'Social | ' + link.network.name,
                  href: link.url,
                  target: '_blank',
                  rel: 'noopener noreferrer',
                  title: link.network.name
                },
                preact.h('img', {
                  src: link.network.icon.url,
                  alt: link.network.icon.alt
                })
              )
            );
          })
        )
      ),
      preact.h(
        'div',
        { 'class': 'mid' },
        preact.h(
          'div',
          { 'class': 'logo' },
          preact.h('img', { src: data.primary_logo.url, alt: data.primary_logo.alt })
        ),
        preact.h(
          'div',
          { 'class': 'products' },
          preact.h(
            'p',
            null,
            data.products
          ),
          preact.h(
            'ul',
            null,
            data.all_product_links.map(function (link, index) {
              return preact.h(
                'li',
                { key: 'product-' + index },
                preact.h(
                  'a',
                  _extends({
                    'data-ga-footer': 'Products | ' + link.title,
                    href: link.url
                  }, link.external && { rel: 'noopener', target: '_blank' }),
                  link.title
                )
              );
            })
          )
        ),
        preact.h(
          'div',
          { 'class': 'resources' },
          preact.h(
            'p',
            null,
            data.resources
          ),
          preact.h(
            'ul',
            null,
            data.resources_links.map(function (link, index) {
              return preact.h(
                'li',
                { key: 'resources-' + index },
                preact.h(
                  'a',
                  _extends({
                    'data-ga-footer': 'Resources | ' + link.title,
                    href: link.url
                  }, link.external && { rel: 'noopener', target: '_blank' }),
                  link.title
                )
              );
            })
          )
        ),
        preact.h(
          'div',
          { 'class': 'partners' },
          preact.h(
            'p',
            null,
            data.partners
          ),
          preact.h(
            'ul',
            null,
            data.partner_links.map(function (link, index) {
              return preact.h(
                'li',
                { key: 'partner-' + index },
                preact.h(
                  'a',
                  _extends({
                    'data-ga-footer': 'Partners | ' + link.title,
                    href: link.url
                  }, link.external && { rel: 'noopener', target: '_blank' }),
                  link.title
                )
              );
            })
          )
        ),
        preact.h(
          'div',
          { 'class': 'company' },
          preact.h(
            'p',
            null,
            data.company
          ),
          preact.h(
            'ul',
            null,
            data.company_links.map(function (link, index) {
              return preact.h(
                'li',
                { key: 'company-' + index },
                preact.h(
                  'a',
                  _extends({
                    'data-ga-footer': 'Company | ' + link.title,
                    href: link.url
                  }, link.external && { rel: 'noopener', target: '_blank' }),
                  link.title
                )
              );
            })
          )
        )
      ),
      preact.h(
        'div',
        { 'class': 'btm' },
        preact.h(
          'p',
          null,
          'Copyright \xA9 ',
          new Date().getFullYear(),
          ' HashiCorp'
        ),
        preact.h(
          'ul',
          null,
          typeof window !== 'undefined' && window.openConsentManager && preact.h(
            'li',
            null,
            preact.h(
              'a',
              {
                'data-ga-footer': 'Bottom | Consent Manager',
                onClick: window.openConsentManager
              },
              'Consent Manager'
            )
          ),
          data.disclaimer_links.map(function (link, index) {
            return preact.h(
              'li',
              { key: 'disclaimer-' + index },
              preact.h(
                'a',
                _extends({
                  'data-ga-footer': 'Bottom | ' + link.title,
                  href: link.url
                }, link.external && { rel: 'noopener', target: '_blank' }),
                link.title
              )
            );
          })
        )
      ),
      preact.h(
        'div',
        { 'class': 'not-a-bug' },
        preact.h(
          'span',
          {
            'data-text': 'This is not a bug on the website, but rather an inside joke for some of our oldest customers.',
            title: 'No, this is not a bug'
          },
          'stdin: is not a tty'
        )
      )
    )
  );
}

module.exports = Footer;
